"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeProjectDefaultNetworkTierXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create"]) -> None: ...

global___ComputeProjectDefaultNetworkTierXTimeouts = ComputeProjectDefaultNetworkTierXTimeouts

@typing_extensions.final
class ComputeProjectDefaultNetworkTier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    network_tier: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeProjectDefaultNetworkTierXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        network_tier: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeProjectDefaultNetworkTierXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "network_tier", b"network_tier", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeProjectDefaultNetworkTier = ComputeProjectDefaultNetworkTier

@typing_extensions.final
class ComputeProjectMetadataXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeProjectMetadataXTimeouts = ComputeProjectMetadataXTimeouts

@typing_extensions.final
class ComputeProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeProjectMetadataXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeProjectMetadataXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "metadata", b"metadata", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeProjectMetadata = ComputeProjectMetadata

@typing_extensions.final
class ComputeProjectMetadataItemXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeProjectMetadataItemXTimeouts = ComputeProjectMetadataItemXTimeouts

@typing_extensions.final
class ComputeProjectMetadataItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    key: builtins.str
    project: builtins.str
    value: builtins.str
    @property
    def timeouts(self) -> global___ComputeProjectMetadataItemXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        key: builtins.str = ...,
        project: builtins.str = ...,
        value: builtins.str = ...,
        timeouts: global___ComputeProjectMetadataItemXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "key", b"key", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "value", b"value"]) -> None: ...

global___ComputeProjectMetadataItem = ComputeProjectMetadataItem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CustomActionTypeConfigurationProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    QUERYABLE_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    key: builtins.bool
    name: builtins.str
    queryable: builtins.bool
    required: builtins.bool
    secret: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        key: builtins.bool = ...,
        name: builtins.str = ...,
        queryable: builtins.bool = ...,
        required: builtins.bool = ...,
        secret: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "key", b"key", "name", b"name", "queryable", b"queryable", "required", b"required", "resource_info", b"resource_info", "secret", b"secret"]) -> None: ...

global___CustomActionTypeConfigurationProperties = CustomActionTypeConfigurationProperties

@typing_extensions.final
class CustomActionTypeArtifactDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAXIMUM_COUNT_FIELD_NUMBER: builtins.int
    MINIMUM_COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    maximum_count: builtins.int
    minimum_count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        maximum_count: builtins.int = ...,
        minimum_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["maximum_count", b"maximum_count", "minimum_count", b"minimum_count", "resource_info", b"resource_info"]) -> None: ...

global___CustomActionTypeArtifactDetails = CustomActionTypeArtifactDetails

@typing_extensions.final
class CustomActionTypeSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENTITY_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    EXECUTION_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    REVISION_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    THIRD_PARTY_CONFIGURATION_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    entity_url_template: builtins.str
    execution_url_template: builtins.str
    revision_url_template: builtins.str
    third_party_configuration_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        entity_url_template: builtins.str = ...,
        execution_url_template: builtins.str = ...,
        revision_url_template: builtins.str = ...,
        third_party_configuration_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_url_template", b"entity_url_template", "execution_url_template", b"execution_url_template", "resource_info", b"resource_info", "revision_url_template", b"revision_url_template", "third_party_configuration_url", b"third_party_configuration_url"]) -> None: ...

global___CustomActionTypeSettings = CustomActionTypeSettings

@typing_extensions.final
class CustomActionType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    CONFIGURATION_PROPERTIES_FIELD_NUMBER: builtins.int
    INPUT_ARTIFACT_DETAILS_FIELD_NUMBER: builtins.int
    OUTPUT_ARTIFACT_DETAILS_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    category: builtins.str
    @property
    def configuration_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomActionTypeConfigurationProperties]: ...
    @property
    def input_artifact_details(self) -> global___CustomActionTypeArtifactDetails: ...
    @property
    def output_artifact_details(self) -> global___CustomActionTypeArtifactDetails: ...
    provider: builtins.str
    @property
    def settings(self) -> global___CustomActionTypeSettings: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        category: builtins.str = ...,
        configuration_properties: collections.abc.Iterable[global___CustomActionTypeConfigurationProperties] | None = ...,
        input_artifact_details: global___CustomActionTypeArtifactDetails | None = ...,
        output_artifact_details: global___CustomActionTypeArtifactDetails | None = ...,
        provider: builtins.str = ...,
        settings: global___CustomActionTypeSettings | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_artifact_details", b"input_artifact_details", "output_artifact_details", b"output_artifact_details", "resource_info", b"resource_info", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "configuration_properties", b"configuration_properties", "input_artifact_details", b"input_artifact_details", "output_artifact_details", b"output_artifact_details", "provider", b"provider", "resource_info", b"resource_info", "settings", b"settings", "tags", b"tags", "version", b"version"]) -> None: ...

global___CustomActionType = CustomActionType

@typing_extensions.final
class CodePipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_ACTION_TYPE_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    @property
    def custom_action_type(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomActionType]: ...
    @property
    def pipeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pipeline]: ...
    @property
    def webhook(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Webhook]: ...
    def __init__(
        self,
        *,
        custom_action_type: collections.abc.Iterable[global___CustomActionType] | None = ...,
        pipeline: collections.abc.Iterable[global___Pipeline] | None = ...,
        webhook: collections.abc.Iterable[global___Webhook] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_action_type", b"custom_action_type", "pipeline", b"pipeline", "webhook", b"webhook"]) -> None: ...

global___CodePipeline = CodePipeline

@typing_extensions.final
class PipelineEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "resource_info", b"resource_info"]) -> None: ...

global___PipelineEncryptionKey = PipelineEncryptionKey

@typing_extensions.final
class PipelineArtifactStore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def encryption_key(self) -> global___PipelineEncryptionKey: ...
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encryption_key: global___PipelineEncryptionKey | None = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption_key", b"encryption_key", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_key", b"encryption_key", "location", b"location", "resource_info", b"resource_info"]) -> None: ...

global___PipelineArtifactStore = PipelineArtifactStore

@typing_extensions.final
class PipelineArtifactStoreMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARTIFACT_STORE_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def artifact_store(self) -> global___PipelineArtifactStore: ...
    region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        artifact_store: global___PipelineArtifactStore | None = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifact_store", b"artifact_store", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_store", b"artifact_store", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___PipelineArtifactStoreMap = PipelineArtifactStoreMap

@typing_extensions.final
class PipelineStageTransition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    reason: builtins.str
    stage_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        reason: builtins.str = ...,
        stage_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["reason", b"reason", "resource_info", b"resource_info", "stage_name", b"stage_name"]) -> None: ...

global___PipelineStageTransition = PipelineStageTransition

@typing_extensions.final
class PipelineActionTypeId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    category: builtins.str
    owner: builtins.str
    provider: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        category: builtins.str = ...,
        owner: builtins.str = ...,
        provider: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "owner", b"owner", "provider", b"provider", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___PipelineActionTypeId = PipelineActionTypeId

@typing_extensions.final
class PipelineInputArtifact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PipelineInputArtifact = PipelineInputArtifact

@typing_extensions.final
class PipelineOutputArtifact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PipelineOutputArtifact = PipelineOutputArtifact

@typing_extensions.final
class PipelineActionDeclaration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigurationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_TYPE_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    INPUT_ARTIFACTS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    OUTPUT_ARTIFACTS_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    RUN_ORDER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def action_type_id(self) -> global___PipelineActionTypeId: ...
    @property
    def configuration(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def input_artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineInputArtifact]: ...
    name: builtins.str
    namespace: builtins.str
    @property
    def output_artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineOutputArtifact]: ...
    region: builtins.str
    role_arn: builtins.str
    run_order: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action_type_id: global___PipelineActionTypeId | None = ...,
        configuration: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        input_artifacts: collections.abc.Iterable[global___PipelineInputArtifact] | None = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        output_artifacts: collections.abc.Iterable[global___PipelineOutputArtifact] | None = ...,
        region: builtins.str = ...,
        role_arn: builtins.str = ...,
        run_order: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action_type_id", b"action_type_id", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_type_id", b"action_type_id", "configuration", b"configuration", "input_artifacts", b"input_artifacts", "name", b"name", "namespace", b"namespace", "output_artifacts", b"output_artifacts", "region", b"region", "resource_info", b"resource_info", "role_arn", b"role_arn", "run_order", b"run_order"]) -> None: ...

global___PipelineActionDeclaration = PipelineActionDeclaration

@typing_extensions.final
class PipelineBlockerDeclaration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PipelineBlockerDeclaration = PipelineBlockerDeclaration

@typing_extensions.final
class PipelineStageDeclaration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    BLOCKERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineActionDeclaration]: ...
    @property
    def blockers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineBlockerDeclaration]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        actions: collections.abc.Iterable[global___PipelineActionDeclaration] | None = ...,
        blockers: collections.abc.Iterable[global___PipelineBlockerDeclaration] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "blockers", b"blockers", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PipelineStageDeclaration = PipelineStageDeclaration

@typing_extensions.final
class Pipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARTIFACT_STORE_FIELD_NUMBER: builtins.int
    ARTIFACT_STORES_FIELD_NUMBER: builtins.int
    DISABLE_INBOUND_STAGE_TRANSITIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESTART_EXECUTION_ON_UPDATE_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    STAGES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def artifact_store(self) -> global___PipelineArtifactStore: ...
    @property
    def artifact_stores(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineArtifactStoreMap]: ...
    @property
    def disable_inbound_stage_transitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineStageTransition]: ...
    name: builtins.str
    restart_execution_on_update: builtins.bool
    role_arn: builtins.str
    @property
    def stages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineStageDeclaration]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        artifact_store: global___PipelineArtifactStore | None = ...,
        artifact_stores: collections.abc.Iterable[global___PipelineArtifactStoreMap] | None = ...,
        disable_inbound_stage_transitions: collections.abc.Iterable[global___PipelineStageTransition] | None = ...,
        name: builtins.str = ...,
        restart_execution_on_update: builtins.bool = ...,
        role_arn: builtins.str = ...,
        stages: collections.abc.Iterable[global___PipelineStageDeclaration] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifact_store", b"artifact_store", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_store", b"artifact_store", "artifact_stores", b"artifact_stores", "disable_inbound_stage_transitions", b"disable_inbound_stage_transitions", "name", b"name", "resource_info", b"resource_info", "restart_execution_on_update", b"restart_execution_on_update", "role_arn", b"role_arn", "stages", b"stages", "tags", b"tags"]) -> None: ...

global___Pipeline = Pipeline

@typing_extensions.final
class WebhookWebhookAuthConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOWED_IP_RANGE_FIELD_NUMBER: builtins.int
    SECRET_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    allowed_ip_range: builtins.str
    secret_token: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allowed_ip_range: builtins.str = ...,
        secret_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_ip_range", b"allowed_ip_range", "resource_info", b"resource_info", "secret_token", b"secret_token"]) -> None: ...

global___WebhookWebhookAuthConfiguration = WebhookWebhookAuthConfiguration

@typing_extensions.final
class WebhookWebhookFilterRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_PATH_FIELD_NUMBER: builtins.int
    MATCH_EQUALS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    json_path: builtins.str
    match_equals: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_path: builtins.str = ...,
        match_equals: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["json_path", b"json_path", "match_equals", b"match_equals", "resource_info", b"resource_info"]) -> None: ...

global___WebhookWebhookFilterRule = WebhookWebhookFilterRule

@typing_extensions.final
class Webhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_FIELD_NUMBER: builtins.int
    TARGET_PIPELINE_FIELD_NUMBER: builtins.int
    TARGET_ACTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_PIPELINE_VERSION_FIELD_NUMBER: builtins.int
    REGISTER_WITH_THIRD_PARTY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def authentication_configuration(self) -> global___WebhookWebhookAuthConfiguration: ...
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WebhookWebhookFilterRule]: ...
    authentication: builtins.str
    target_pipeline: builtins.str
    target_action: builtins.str
    name: builtins.str
    target_pipeline_version: builtins.int
    register_with_third_party: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authentication_configuration: global___WebhookWebhookAuthConfiguration | None = ...,
        filters: collections.abc.Iterable[global___WebhookWebhookFilterRule] | None = ...,
        authentication: builtins.str = ...,
        target_pipeline: builtins.str = ...,
        target_action: builtins.str = ...,
        name: builtins.str = ...,
        target_pipeline_version: builtins.int = ...,
        register_with_third_party: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication", b"authentication", "authentication_configuration", b"authentication_configuration", "filters", b"filters", "name", b"name", "register_with_third_party", b"register_with_third_party", "resource_info", b"resource_info", "target_action", b"target_action", "target_pipeline", b"target_pipeline", "target_pipeline_version", b"target_pipeline_version"]) -> None: ...

global___Webhook = Webhook



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.rbac.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.kubernetes/kubernetes_io.k8s.api.rbac.v1.proto\x12\x1boak9.tython.k8s.api.rbac.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xa8\x01\n\x0f\x41ggregationRule\x12\\\n\x16\x63luster_role_selectors\x18\x01 \x03(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x02\n\x0b\x43lusterRole\x12\x46\n\x10\x61ggregation_rule\x18\x01 \x01(\x0b\x32,.oak9.tython.k8s.api.rbac.v1.AggregationRule\x12\x13\n\x0b\x61pi_version\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x05rules\x18\x05 \x03(\x0b\x32\'.oak9.tython.k8s.api.rbac.v1.PolicyRule\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x02\n\x12\x43lusterRoleBinding\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x08role_ref\x18\x04 \x01(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.RoleRef\x12\x36\n\x08subjects\x18\x05 \x03(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.Subject\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x16\x43lusterRoleBindingList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.rbac.v1.ClusterRoleBinding\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x01\n\x0f\x43lusterRoleList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x37\n\x05items\x18\x02 \x03(\x0b\x32(.oak9.tython.k8s.api.rbac.v1.ClusterRole\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\nPolicyRule\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x1b\n\x13non_resource_u_r_ls\x18\x02 \x03(\t\x12\x16\n\x0eresource_names\x18\x03 \x03(\t\x12\x11\n\tresources\x18\x04 \x03(\t\x12\r\n\x05verbs\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe7\x01\n\x04Role\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x05rules\x18\x04 \x03(\x0b\x32\'.oak9.tython.k8s.api.rbac.v1.PolicyRule\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x02\n\x0bRoleBinding\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x08role_ref\x18\x04 \x01(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.RoleRef\x12\x36\n\x08subjects\x18\x05 \x03(\x0b\x32$.oak9.tython.k8s.api.rbac.v1.Subject\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x01\n\x0fRoleBindingList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x37\n\x05items\x18\x02 \x03(\x0b\x32(.oak9.tython.k8s.api.rbac.v1.RoleBinding\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe3\x01\n\x08RoleList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.oak9.tython.k8s.api.rbac.v1.Role\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"q\n\x07RoleRef\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x84\x01\n\x07Subject\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AGGREGATIONRULE._serialized_start=167
  _AGGREGATIONRULE._serialized_end=335
  _CLUSTERROLE._serialized_start=338
  _CLUSTERROLE._serialized_end=648
  _CLUSTERROLEBINDING._serialized_start=651
  _CLUSTERROLEBINDING._serialized_end=952
  _CLUSTERROLEBINDINGLIST._serialized_start=955
  _CLUSTERROLEBINDINGLIST._serialized_end=1210
  _CLUSTERROLELIST._serialized_start=1213
  _CLUSTERROLELIST._serialized_end=1454
  _POLICYRULE._serialized_start=1457
  _POLICYRULE._serialized_end=1633
  _ROLE._serialized_start=1636
  _ROLE._serialized_end=1867
  _ROLEBINDING._serialized_start=1870
  _ROLEBINDING._serialized_end=2164
  _ROLEBINDINGLIST._serialized_start=2167
  _ROLEBINDINGLIST._serialized_end=2408
  _ROLELIST._serialized_start=2411
  _ROLELIST._serialized_end=2638
  _ROLEREF._serialized_start=2640
  _ROLEREF._serialized_end=2753
  _SUBJECT._serialized_start=2756
  _SUBJECT._serialized_end=2888
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeRouterXBgpXAdvertisedIpRanges(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    RANGE_FIELD_NUMBER: builtins.int
    description: builtins.str
    range: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        range: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "range", b"range"]) -> None: ...

global___ComputeRouterXBgpXAdvertisedIpRanges = ComputeRouterXBgpXAdvertisedIpRanges

@typing_extensions.final
class ComputeRouterXBgp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVERTISE_MODE_FIELD_NUMBER: builtins.int
    ADVERTISED_GROUPS_FIELD_NUMBER: builtins.int
    ASN_FIELD_NUMBER: builtins.int
    KEEPALIVE_INTERVAL_FIELD_NUMBER: builtins.int
    ADVERTISED_IP_RANGES_FIELD_NUMBER: builtins.int
    advertise_mode: builtins.str
    @property
    def advertised_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    asn: builtins.float
    keepalive_interval: builtins.float
    @property
    def advertised_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRouterXBgpXAdvertisedIpRanges]: ...
    def __init__(
        self,
        *,
        advertise_mode: builtins.str = ...,
        advertised_groups: collections.abc.Iterable[builtins.str] | None = ...,
        asn: builtins.float = ...,
        keepalive_interval: builtins.float = ...,
        advertised_ip_ranges: collections.abc.Iterable[global___ComputeRouterXBgpXAdvertisedIpRanges] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["advertise_mode", b"advertise_mode", "advertised_groups", b"advertised_groups", "advertised_ip_ranges", b"advertised_ip_ranges", "asn", b"asn", "keepalive_interval", b"keepalive_interval"]) -> None: ...

global___ComputeRouterXBgp = ComputeRouterXBgp

@typing_extensions.final
class ComputeRouterXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRouterXTimeouts = ComputeRouterXTimeouts

@typing_extensions.final
class ComputeRouter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENCRYPTED_INTERCONNECT_ROUTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    BGP_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    encrypted_interconnect_router: builtins.bool
    id: builtins.str
    name: builtins.str
    network: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def bgp(self) -> global___ComputeRouterXBgp: ...
    @property
    def timeouts(self) -> global___ComputeRouterXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        encrypted_interconnect_router: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        bgp: global___ComputeRouterXBgp | None = ...,
        timeouts: global___ComputeRouterXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bgp", b"bgp", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bgp", b"bgp", "creation_timestamp", b"creation_timestamp", "description", b"description", "encrypted_interconnect_router", b"encrypted_interconnect_router", "id", b"id", "name", b"name", "network", b"network", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRouter = ComputeRouter

@typing_extensions.final
class ComputeRouterInterfaceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeRouterInterfaceXTimeouts = ComputeRouterInterfaceXTimeouts

@typing_extensions.final
class ComputeRouterInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INTERCONNECT_ATTACHMENT_FIELD_NUMBER: builtins.int
    IP_RANGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    VPN_TUNNEL_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    interconnect_attachment: builtins.str
    ip_range: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    router: builtins.str
    vpn_tunnel: builtins.str
    @property
    def timeouts(self) -> global___ComputeRouterInterfaceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        interconnect_attachment: builtins.str = ...,
        ip_range: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        router: builtins.str = ...,
        vpn_tunnel: builtins.str = ...,
        timeouts: global___ComputeRouterInterfaceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "interconnect_attachment", b"interconnect_attachment", "ip_range", b"ip_range", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "router", b"router", "timeouts", b"timeouts", "vpn_tunnel", b"vpn_tunnel"]) -> None: ...

global___ComputeRouterInterface = ComputeRouterInterface

@typing_extensions.final
class ComputeRouterNatXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    filter: builtins.str
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "filter", b"filter"]) -> None: ...

global___ComputeRouterNatXLogConfig = ComputeRouterNatXLogConfig

@typing_extensions.final
class ComputeRouterNatXSubnetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SECONDARY_IP_RANGE_NAMES_FIELD_NUMBER: builtins.int
    SOURCE_IP_RANGES_TO_NAT_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def secondary_ip_range_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_ip_ranges_to_nat(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        secondary_ip_range_names: collections.abc.Iterable[builtins.str] | None = ...,
        source_ip_ranges_to_nat: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "secondary_ip_range_names", b"secondary_ip_range_names", "source_ip_ranges_to_nat", b"source_ip_ranges_to_nat"]) -> None: ...

global___ComputeRouterNatXSubnetwork = ComputeRouterNatXSubnetwork

@typing_extensions.final
class ComputeRouterNatXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRouterNatXTimeouts = ComputeRouterNatXTimeouts

@typing_extensions.final
class ComputeRouterNat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRAIN_NAT_IPS_FIELD_NUMBER: builtins.int
    ENABLE_DYNAMIC_PORT_ALLOCATION_FIELD_NUMBER: builtins.int
    ENABLE_ENDPOINT_INDEPENDENT_MAPPING_FIELD_NUMBER: builtins.int
    ICMP_IDLE_TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MAX_PORTS_PER_VM_FIELD_NUMBER: builtins.int
    MIN_PORTS_PER_VM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAT_IP_ALLOCATE_OPTION_FIELD_NUMBER: builtins.int
    NAT_IPS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    SOURCE_SUBNETWORK_IP_RANGES_TO_NAT_FIELD_NUMBER: builtins.int
    TCP_ESTABLISHED_IDLE_TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    TCP_TRANSITORY_IDLE_TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    UDP_IDLE_TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def drain_nat_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_dynamic_port_allocation: builtins.bool
    enable_endpoint_independent_mapping: builtins.bool
    icmp_idle_timeout_sec: builtins.float
    id: builtins.str
    max_ports_per_vm: builtins.float
    min_ports_per_vm: builtins.float
    name: builtins.str
    nat_ip_allocate_option: builtins.str
    @property
    def nat_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    router: builtins.str
    source_subnetwork_ip_ranges_to_nat: builtins.str
    tcp_established_idle_timeout_sec: builtins.float
    tcp_transitory_idle_timeout_sec: builtins.float
    udp_idle_timeout_sec: builtins.float
    @property
    def log_config(self) -> global___ComputeRouterNatXLogConfig: ...
    @property
    def subnetwork(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRouterNatXSubnetwork]: ...
    @property
    def timeouts(self) -> global___ComputeRouterNatXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        drain_nat_ips: collections.abc.Iterable[builtins.str] | None = ...,
        enable_dynamic_port_allocation: builtins.bool = ...,
        enable_endpoint_independent_mapping: builtins.bool = ...,
        icmp_idle_timeout_sec: builtins.float = ...,
        id: builtins.str = ...,
        max_ports_per_vm: builtins.float = ...,
        min_ports_per_vm: builtins.float = ...,
        name: builtins.str = ...,
        nat_ip_allocate_option: builtins.str = ...,
        nat_ips: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        router: builtins.str = ...,
        source_subnetwork_ip_ranges_to_nat: builtins.str = ...,
        tcp_established_idle_timeout_sec: builtins.float = ...,
        tcp_transitory_idle_timeout_sec: builtins.float = ...,
        udp_idle_timeout_sec: builtins.float = ...,
        log_config: global___ComputeRouterNatXLogConfig | None = ...,
        subnetwork: collections.abc.Iterable[global___ComputeRouterNatXSubnetwork] | None = ...,
        timeouts: global___ComputeRouterNatXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_config", b"log_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["drain_nat_ips", b"drain_nat_ips", "enable_dynamic_port_allocation", b"enable_dynamic_port_allocation", "enable_endpoint_independent_mapping", b"enable_endpoint_independent_mapping", "icmp_idle_timeout_sec", b"icmp_idle_timeout_sec", "id", b"id", "log_config", b"log_config", "max_ports_per_vm", b"max_ports_per_vm", "min_ports_per_vm", b"min_ports_per_vm", "name", b"name", "nat_ip_allocate_option", b"nat_ip_allocate_option", "nat_ips", b"nat_ips", "project", b"project", "region", b"region", "resource_info", b"resource_info", "router", b"router", "source_subnetwork_ip_ranges_to_nat", b"source_subnetwork_ip_ranges_to_nat", "subnetwork", b"subnetwork", "tcp_established_idle_timeout_sec", b"tcp_established_idle_timeout_sec", "tcp_transitory_idle_timeout_sec", b"tcp_transitory_idle_timeout_sec", "timeouts", b"timeouts", "udp_idle_timeout_sec", b"udp_idle_timeout_sec"]) -> None: ...

global___ComputeRouterNat = ComputeRouterNat

@typing_extensions.final
class ComputeRouterPeerXAdvertisedIpRanges(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    RANGE_FIELD_NUMBER: builtins.int
    description: builtins.str
    range: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        range: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "range", b"range"]) -> None: ...

global___ComputeRouterPeerXAdvertisedIpRanges = ComputeRouterPeerXAdvertisedIpRanges

@typing_extensions.final
class ComputeRouterPeerXBfd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_RECEIVE_INTERVAL_FIELD_NUMBER: builtins.int
    MIN_TRANSMIT_INTERVAL_FIELD_NUMBER: builtins.int
    MULTIPLIER_FIELD_NUMBER: builtins.int
    SESSION_INITIALIZATION_MODE_FIELD_NUMBER: builtins.int
    min_receive_interval: builtins.float
    min_transmit_interval: builtins.float
    multiplier: builtins.float
    session_initialization_mode: builtins.str
    def __init__(
        self,
        *,
        min_receive_interval: builtins.float = ...,
        min_transmit_interval: builtins.float = ...,
        multiplier: builtins.float = ...,
        session_initialization_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_receive_interval", b"min_receive_interval", "min_transmit_interval", b"min_transmit_interval", "multiplier", b"multiplier", "session_initialization_mode", b"session_initialization_mode"]) -> None: ...

global___ComputeRouterPeerXBfd = ComputeRouterPeerXBfd

@typing_extensions.final
class ComputeRouterPeerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRouterPeerXTimeouts = ComputeRouterPeerXTimeouts

@typing_extensions.final
class ComputeRouterPeer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVERTISE_MODE_FIELD_NUMBER: builtins.int
    ADVERTISED_GROUPS_FIELD_NUMBER: builtins.int
    ADVERTISED_ROUTE_PRIORITY_FIELD_NUMBER: builtins.int
    ENABLE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INTERFACE_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PEER_ASN_FIELD_NUMBER: builtins.int
    PEER_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    ADVERTISED_IP_RANGES_FIELD_NUMBER: builtins.int
    BFD_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    advertise_mode: builtins.str
    @property
    def advertised_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    advertised_route_priority: builtins.float
    enable: builtins.bool
    id: builtins.str
    interface: builtins.str
    ip_address: builtins.str
    management_type: builtins.str
    name: builtins.str
    peer_asn: builtins.float
    peer_ip_address: builtins.str
    project: builtins.str
    region: builtins.str
    router: builtins.str
    @property
    def advertised_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRouterPeerXAdvertisedIpRanges]: ...
    @property
    def bfd(self) -> global___ComputeRouterPeerXBfd: ...
    @property
    def timeouts(self) -> global___ComputeRouterPeerXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        advertise_mode: builtins.str = ...,
        advertised_groups: collections.abc.Iterable[builtins.str] | None = ...,
        advertised_route_priority: builtins.float = ...,
        enable: builtins.bool = ...,
        id: builtins.str = ...,
        interface: builtins.str = ...,
        ip_address: builtins.str = ...,
        management_type: builtins.str = ...,
        name: builtins.str = ...,
        peer_asn: builtins.float = ...,
        peer_ip_address: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        router: builtins.str = ...,
        advertised_ip_ranges: collections.abc.Iterable[global___ComputeRouterPeerXAdvertisedIpRanges] | None = ...,
        bfd: global___ComputeRouterPeerXBfd | None = ...,
        timeouts: global___ComputeRouterPeerXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bfd", b"bfd", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["advertise_mode", b"advertise_mode", "advertised_groups", b"advertised_groups", "advertised_ip_ranges", b"advertised_ip_ranges", "advertised_route_priority", b"advertised_route_priority", "bfd", b"bfd", "enable", b"enable", "id", b"id", "interface", b"interface", "ip_address", b"ip_address", "management_type", b"management_type", "name", b"name", "peer_asn", b"peer_asn", "peer_ip_address", b"peer_ip_address", "project", b"project", "region", b"region", "resource_info", b"resource_info", "router", b"router", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRouterPeer = ComputeRouterPeer



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticache_replicationgroup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*aws/aws_elasticache_replicationgroup.proto\x12,oak9.tython.aws.elasticache_replicationgroup\x1a\x13shared/shared.proto\"\xe5\x01\n&ReplicationGroupNodeGroupConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rnode_group_id\x18\x02 \x01(\t\x12!\n\x19primary_availability_zone\x18\x03 \x01(\t\x12\"\n\x1areplica_availability_zones\x18\x04 \x03(\t\x12\x15\n\rreplica_count\x18\x05 \x01(\x05\x12\r\n\x05slots\x18\x06 \x01(\t\"\x9a\t\n\x10ReplicationGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1a\x61t_rest_encryption_enabled\x18\x02 \x01(\x08\x12\x12\n\nauth_token\x18\x03 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x04 \x01(\x08\x12\"\n\x1a\x61utomatic_failover_enabled\x18\x05 \x01(\x08\x12\x17\n\x0f\x63\x61\x63he_node_type\x18\x06 \x01(\t\x12\"\n\x1a\x63\x61\x63he_parameter_group_name\x18\x07 \x01(\t\x12\"\n\x1a\x63\x61\x63he_security_group_names\x18\x08 \x03(\t\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\t \x01(\t\x12\x0e\n\x06\x65ngine\x18\n \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x0b \x01(\t\x12\x12\n\nkms_key_id\x18\x0c \x01(\t\x12\x18\n\x10multi_az_enabled\x18\r \x01(\x08\x12v\n\x18node_group_configuration\x18\x0e \x03(\x0b\x32T.oak9.tython.aws.elasticache_replicationgroup.ReplicationGroupNodeGroupConfiguration\x12\x1e\n\x16notification_topic_arn\x18\x0f \x01(\t\x12\x1a\n\x12num_cache_clusters\x18\x10 \x01(\x05\x12\x17\n\x0fnum_node_groups\x18\x11 \x01(\x05\x12\x0c\n\x04port\x18\x12 \x01(\x05\x12#\n\x1bpreferred_cache_cluster_azs\x18\x13 \x03(\t\x12$\n\x1cpreferred_maintenance_window\x18\x14 \x01(\t\x12\x1a\n\x12primary_cluster_id\x18\x15 \x01(\t\x12\x1f\n\x17replicas_per_node_group\x18\x16 \x01(\x05\x12%\n\x1dreplication_group_description\x18\x17 \x01(\t\x12\x1c\n\x14replication_group_id\x18\x18 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x19 \x03(\t\x12\x15\n\rsnapshot_arns\x18\x1a \x03(\t\x12\x15\n\rsnapshot_name\x18\x1b \x01(\t\x12 \n\x18snapshot_retention_limit\x18\x1c \x01(\x05\x12\x17\n\x0fsnapshot_window\x18\x1d \x01(\t\x12\x1f\n\x17snapshotting_cluster_id\x18\x1e \x01(\t\x12V\n\x04tags\x18\x1f \x03(\x0b\x32H.oak9.tython.aws.elasticache_replicationgroup.ReplicationGroup.TagsEntry\x12\"\n\x1atransit_encryption_enabled\x18  \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x03\n\x1c\x45lastiCache_ReplicationGroup\x12Y\n\x11replication_group\x18\x01 \x01(\x0b\x32>.oak9.tython.aws.elasticache_replicationgroup.ReplicationGroup\x12S\n\x0esecurity_group\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.elasticache_replicationgroup.SecurityGroup\x12\x62\n\x16security_group_ingress\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.elasticache_replicationgroup.SecurityGroupIngress\x12O\n\x0csubnet_group\x18\x04 \x01(\x0b\x32\x39.oak9.tython.aws.elasticache_replicationgroup.SubnetGroup\"]\n\rSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xba\x01\n\x14SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x61\x63he_security_group_name\x18\x02 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x03 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x04 \x01(\t\"\x90\x01\n\x0bSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticache_replicationgroup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPLICATIONGROUP_TAGSENTRY._options = None
  _REPLICATIONGROUP_TAGSENTRY._serialized_options = b'8\001'
  _REPLICATIONGROUPNODEGROUPCONFIGURATION._serialized_start=114
  _REPLICATIONGROUPNODEGROUPCONFIGURATION._serialized_end=343
  _REPLICATIONGROUP._serialized_start=346
  _REPLICATIONGROUP._serialized_end=1524
  _REPLICATIONGROUP_TAGSENTRY._serialized_start=1481
  _REPLICATIONGROUP_TAGSENTRY._serialized_end=1524
  _ELASTICACHE_REPLICATIONGROUP._serialized_start=1527
  _ELASTICACHE_REPLICATIONGROUP._serialized_end=1914
  _SECURITYGROUP._serialized_start=1916
  _SECURITYGROUP._serialized_end=2009
  _SECURITYGROUPINGRESS._serialized_start=2012
  _SECURITYGROUPINGRESS._serialized_end=2198
  _SUBNETGROUP._serialized_start=2201
  _SUBNETGROUP._serialized_end=2345
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BrokerConfigurationId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    revision: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        revision: builtins.int = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___BrokerConfigurationId = BrokerConfigurationId

@typing_extensions.final
class BrokerMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    TIME_OF_DAY_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    day_of_week: builtins.str
    time_of_day: builtins.str
    time_zone: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        day_of_week: builtins.str = ...,
        time_of_day: builtins.str = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week", "resource_info", b"resource_info", "time_of_day", b"time_of_day", "time_zone", b"time_zone"]) -> None: ...

global___BrokerMaintenanceWindow = BrokerMaintenanceWindow

@typing_extensions.final
class BrokerInterBrokerCred(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___BrokerInterBrokerCred = BrokerInterBrokerCred

@typing_extensions.final
class BrokerServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    USER_ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_BASE_FIELD_NUMBER: builtins.int
    USER_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_USERNAME_FIELD_NUMBER: builtins.int
    ROLE_BASE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_PASSWORD_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    user_role_name: builtins.str
    user_search_matching: builtins.str
    role_name: builtins.str
    user_base: builtins.str
    user_search_subtree: builtins.bool
    role_search_matching: builtins.str
    service_account_username: builtins.str
    role_base: builtins.str
    service_account_password: builtins.str
    role_search_subtree: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        user_role_name: builtins.str = ...,
        user_search_matching: builtins.str = ...,
        role_name: builtins.str = ...,
        user_base: builtins.str = ...,
        user_search_subtree: builtins.bool = ...,
        role_search_matching: builtins.str = ...,
        service_account_username: builtins.str = ...,
        role_base: builtins.str = ...,
        service_account_password: builtins.str = ...,
        role_search_subtree: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosts", b"hosts", "resource_info", b"resource_info", "role_base", b"role_base", "role_name", b"role_name", "role_search_matching", b"role_search_matching", "role_search_subtree", b"role_search_subtree", "service_account_password", b"service_account_password", "service_account_username", b"service_account_username", "user_base", b"user_base", "user_role_name", b"user_role_name", "user_search_matching", b"user_search_matching", "user_search_subtree", b"user_search_subtree"]) -> None: ...

global___BrokerServerMetadata = BrokerServerMetadata

@typing_extensions.final
class BrokerLdapMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTER_BROKER_CREDS_FIELD_NUMBER: builtins.int
    SERVER_METADATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def inter_broker_creds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BrokerInterBrokerCred]: ...
    @property
    def server_metadata(self) -> global___BrokerServerMetadata: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        inter_broker_creds: collections.abc.Iterable[global___BrokerInterBrokerCred] | None = ...,
        server_metadata: global___BrokerServerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "server_metadata", b"server_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inter_broker_creds", b"inter_broker_creds", "resource_info", b"resource_info", "server_metadata", b"server_metadata"]) -> None: ...

global___BrokerLdapMetadata = BrokerLdapMetadata

@typing_extensions.final
class BrokerUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CONSOLE_ACCESS_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    username: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    console_access: builtins.bool
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        username: builtins.str = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        console_access: builtins.bool = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["console_access", b"console_access", "groups", b"groups", "password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___BrokerUser = BrokerUser

@typing_extensions.final
class BrokerLogList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUDIT_FIELD_NUMBER: builtins.int
    GENERAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    audit: builtins.bool
    general: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        audit: builtins.bool = ...,
        general: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit", b"audit", "general", b"general", "resource_info", b"resource_info"]) -> None: ...

global___BrokerLogList = BrokerLogList

@typing_extensions.final
class BrokerLdapServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    USER_ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    ROLE_NAME_FIELD_NUMBER: builtins.int
    USER_BASE_FIELD_NUMBER: builtins.int
    USER_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_MATCHING_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_USERNAME_FIELD_NUMBER: builtins.int
    ROLE_BASE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_PASSWORD_FIELD_NUMBER: builtins.int
    ROLE_SEARCH_SUBTREE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    user_role_name: builtins.str
    user_search_matching: builtins.str
    role_name: builtins.str
    user_base: builtins.str
    user_search_subtree: builtins.bool
    role_search_matching: builtins.str
    service_account_username: builtins.str
    role_base: builtins.str
    service_account_password: builtins.str
    role_search_subtree: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        user_role_name: builtins.str = ...,
        user_search_matching: builtins.str = ...,
        role_name: builtins.str = ...,
        user_base: builtins.str = ...,
        user_search_subtree: builtins.bool = ...,
        role_search_matching: builtins.str = ...,
        service_account_username: builtins.str = ...,
        role_base: builtins.str = ...,
        service_account_password: builtins.str = ...,
        role_search_subtree: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosts", b"hosts", "resource_info", b"resource_info", "role_base", b"role_base", "role_name", b"role_name", "role_search_matching", b"role_search_matching", "role_search_subtree", b"role_search_subtree", "service_account_password", b"service_account_password", "service_account_username", b"service_account_username", "user_base", b"user_base", "user_role_name", b"user_role_name", "user_search_matching", b"user_search_matching", "user_search_subtree", b"user_search_subtree"]) -> None: ...

global___BrokerLdapServerMetadata = BrokerLdapServerMetadata

@typing_extensions.final
class BrokerEncryptionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    USE_AWS_OWNED_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_id: builtins.str
    use_aws_owned_key: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_id: builtins.str = ...,
        use_aws_owned_key: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_id", b"kms_key_id", "resource_info", b"resource_info", "use_aws_owned_key", b"use_aws_owned_key"]) -> None: ...

global___BrokerEncryptionOptions = BrokerEncryptionOptions

@typing_extensions.final
class BrokerTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___BrokerTagsEntry = BrokerTagsEntry

@typing_extensions.final
class Broker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHENTICATION_STRATEGY_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_START_TIME_FIELD_NUMBER: builtins.int
    LDAP_METADATA_FIELD_NUMBER: builtins.int
    HOST_INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    AUTO_MINOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    BROKER_NAME_FIELD_NUMBER: builtins.int
    LDAP_SERVER_METADATA_FIELD_NUMBER: builtins.int
    DEPLOYMENT_MODE_FIELD_NUMBER: builtins.int
    ENGINE_TYPE_FIELD_NUMBER: builtins.int
    PUBLICLY_ACCESSIBLE_FIELD_NUMBER: builtins.int
    ENCRYPTION_OPTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    storage_type: builtins.str
    engine_version: builtins.str
    @property
    def configuration(self) -> global___BrokerConfigurationId: ...
    authentication_strategy: builtins.str
    @property
    def maintenance_window_start_time(self) -> global___BrokerMaintenanceWindow: ...
    @property
    def ldap_metadata(self) -> global___BrokerLdapMetadata: ...
    host_instance_type: builtins.str
    auto_minor_version_upgrade: builtins.bool
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BrokerUser]: ...
    @property
    def logs(self) -> global___BrokerLogList: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    broker_name: builtins.str
    @property
    def ldap_server_metadata(self) -> global___BrokerLdapServerMetadata: ...
    deployment_mode: builtins.str
    engine_type: builtins.str
    publicly_accessible: builtins.bool
    @property
    def encryption_options(self) -> global___BrokerEncryptionOptions: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BrokerTagsEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        storage_type: builtins.str = ...,
        engine_version: builtins.str = ...,
        configuration: global___BrokerConfigurationId | None = ...,
        authentication_strategy: builtins.str = ...,
        maintenance_window_start_time: global___BrokerMaintenanceWindow | None = ...,
        ldap_metadata: global___BrokerLdapMetadata | None = ...,
        host_instance_type: builtins.str = ...,
        auto_minor_version_upgrade: builtins.bool = ...,
        users: collections.abc.Iterable[global___BrokerUser] | None = ...,
        logs: global___BrokerLogList | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        broker_name: builtins.str = ...,
        ldap_server_metadata: global___BrokerLdapServerMetadata | None = ...,
        deployment_mode: builtins.str = ...,
        engine_type: builtins.str = ...,
        publicly_accessible: builtins.bool = ...,
        encryption_options: global___BrokerEncryptionOptions | None = ...,
        tags: collections.abc.Iterable[global___BrokerTagsEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "encryption_options", b"encryption_options", "ldap_metadata", b"ldap_metadata", "ldap_server_metadata", b"ldap_server_metadata", "logs", b"logs", "maintenance_window_start_time", b"maintenance_window_start_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_strategy", b"authentication_strategy", "auto_minor_version_upgrade", b"auto_minor_version_upgrade", "broker_name", b"broker_name", "configuration", b"configuration", "deployment_mode", b"deployment_mode", "encryption_options", b"encryption_options", "engine_type", b"engine_type", "engine_version", b"engine_version", "host_instance_type", b"host_instance_type", "ldap_metadata", b"ldap_metadata", "ldap_server_metadata", b"ldap_server_metadata", "logs", b"logs", "maintenance_window_start_time", b"maintenance_window_start_time", "publicly_accessible", b"publicly_accessible", "resource_info", b"resource_info", "security_groups", b"security_groups", "storage_type", b"storage_type", "subnet_ids", b"subnet_ids", "tags", b"tags", "users", b"users"]) -> None: ...

global___Broker = Broker

@typing_extensions.final
class AmazonMQ(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    CONFIGURATION_ASSOCIATION_FIELD_NUMBER: builtins.int
    @property
    def broker(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Broker]: ...
    @property
    def configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Configuration]: ...
    @property
    def configuration_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationAssociation]: ...
    def __init__(
        self,
        *,
        broker: collections.abc.Iterable[global___Broker] | None = ...,
        configuration: collections.abc.Iterable[global___Configuration] | None = ...,
        configuration_association: collections.abc.Iterable[global___ConfigurationAssociation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker", b"broker", "configuration", b"configuration", "configuration_association", b"configuration_association"]) -> None: ...

global___AmazonMQ = AmazonMQ

@typing_extensions.final
class ConfigurationTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ConfigurationTagsEntry = ConfigurationTagsEntry

@typing_extensions.final
class Configuration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENGINE_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    engine_version: builtins.str
    description: builtins.str
    engine_type: builtins.str
    data: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationTagsEntry]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        engine_version: builtins.str = ...,
        description: builtins.str = ...,
        engine_type: builtins.str = ...,
        data: builtins.str = ...,
        tags: collections.abc.Iterable[global___ConfigurationTagsEntry] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "description", b"description", "engine_type", b"engine_type", "engine_version", b"engine_version", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Configuration = Configuration

@typing_extensions.final
class ConfigurationAssociationConfigurationId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    revision: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        revision: builtins.int = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___ConfigurationAssociationConfigurationId = ConfigurationAssociationConfigurationId

@typing_extensions.final
class ConfigurationAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BROKER_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    broker: builtins.str
    @property
    def configuration(self) -> global___ConfigurationAssociationConfigurationId: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        broker: builtins.str = ...,
        configuration: global___ConfigurationAssociationConfigurationId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker", b"broker", "configuration", b"configuration", "resource_info", b"resource_info"]) -> None: ...

global___ConfigurationAssociation = ConfigurationAssociation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticache_cachecluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&aws/aws_elasticache_cachecluster.proto\x12(oak9.tython.aws.elasticache_cachecluster\x1a\x13shared/shared.proto\"\xfa\x05\n\x0c\x43\x61\x63heCluster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61z_mode\x18\x02 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x03 \x01(\x08\x12\x17\n\x0f\x63\x61\x63he_node_type\x18\x04 \x01(\t\x12\"\n\x1a\x63\x61\x63he_parameter_group_name\x18\x05 \x01(\t\x12\"\n\x1a\x63\x61\x63he_security_group_names\x18\x06 \x03(\t\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\x07 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x08 \x01(\t\x12\x0e\n\x06\x65ngine\x18\t \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\n \x01(\t\x12\x1e\n\x16notification_topic_arn\x18\x0b \x01(\t\x12\x17\n\x0fnum_cache_nodes\x18\x0c \x01(\x05\x12\x0c\n\x04port\x18\r \x01(\x05\x12#\n\x1bpreferred_availability_zone\x18\x0e \x01(\t\x12$\n\x1cpreferred_availability_zones\x18\x0f \x03(\t\x12$\n\x1cpreferred_maintenance_window\x18\x10 \x01(\t\x12\x15\n\rsnapshot_arns\x18\x11 \x03(\t\x12\x15\n\rsnapshot_name\x18\x12 \x01(\t\x12 \n\x18snapshot_retention_limit\x18\x13 \x01(\x05\x12\x17\n\x0fsnapshot_window\x18\x14 \x01(\t\x12N\n\x04tags\x18\x15 \x03(\x0b\x32@.oak9.tython.aws.elasticache_cachecluster.CacheCluster.TagsEntry\x12\x1e\n\x16vpc_security_group_ids\x18\x16 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe7\x02\n\x18\x45lastiCache_CacheCluster\x12M\n\rcache_cluster\x18\x01 \x01(\x0b\x32\x36.oak9.tython.aws.elasticache_cachecluster.CacheCluster\x12O\n\x0esecurity_group\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.elasticache_cachecluster.SecurityGroup\x12^\n\x16security_group_ingress\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.elasticache_cachecluster.SecurityGroupIngress\x12K\n\x0csubnet_group\x18\x04 \x01(\x0b\x32\x35.oak9.tython.aws.elasticache_cachecluster.SubnetGroup\"]\n\rSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xba\x01\n\x14SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x61\x63he_security_group_name\x18\x02 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x03 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x04 \x01(\t\"\x90\x01\n\x0bSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61\x63he_subnet_group_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticache_cachecluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CACHECLUSTER_TAGSENTRY._options = None
  _CACHECLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _CACHECLUSTER._serialized_start=106
  _CACHECLUSTER._serialized_end=868
  _CACHECLUSTER_TAGSENTRY._serialized_start=825
  _CACHECLUSTER_TAGSENTRY._serialized_end=868
  _ELASTICACHE_CACHECLUSTER._serialized_start=871
  _ELASTICACHE_CACHECLUSTER._serialized_end=1230
  _SECURITYGROUP._serialized_start=1232
  _SECURITYGROUP._serialized_end=1325
  _SECURITYGROUPINGRESS._serialized_start=1328
  _SECURITYGROUPINGRESS._serialized_end=1514
  _SUBNETGROUP._serialized_start=1517
  _SUBNETGROUP._serialized_end=1661
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_container_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleContainer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_CLUSTER_FIELD_NUMBER: builtins.int
    CONTAINER_NODE_POOL_FIELD_NUMBER: builtins.int
    @property
    def container_cluster(self) -> gcp.gcp_container_pb2.ContainerCluster: ...
    @property
    def container_node_pool(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_container_pb2.ContainerNodePool]: ...
    def __init__(
        self,
        *,
        container_cluster: gcp.gcp_container_pb2.ContainerCluster | None = ...,
        container_node_pool: collections.abc.Iterable[gcp.gcp_container_pb2.ContainerNodePool] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_cluster", b"container_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_cluster", b"container_cluster", "container_node_pool", b"container_node_pool"]) -> None: ...

global___GoogleContainer = GoogleContainer
